# Linops

## Operations
```{eval-rst}
.. autosummary::
    :toctree: generated
    :template: linop_template.rst
    :nosignatures:

    torchlinops.ArrayToBlocks
    torchlinops.Dense
    torchlinops.Diagonal
    torchlinops.FFT
    torchlinops.NUFFT
    torchlinops.PadLast

```

```{eval-rst}
.. autosummary::
   :toctree: generated
   :template: linop_template.rst
   :nosignatures:

   torchlinops.Add
   torchlinops.Chain
   torchlinops.Concat
   torchlinops.Stack
```

## Other
```{eval-rst}
.. autosummary::
   :toctree: generated
   :template: linop_template.rst
   :nosignatures:

   torchlinops.BreakpointLinop
   torchlinops.ToDevice
```
